@@ -70,9 +70,12 @@ class UserService:
         expiry_seconds: Optional[int] = None,
     ) -> Session:
         body = {
-            "identity": identity,
             "credential_type": str(cred_type),
         }
+        if cred_type == CredentialType.OAUTH:
+            body["id_token"] = identity
+        else:
+            body["identity"] = identity
 
         if cred_type == CredentialType.USERNAME:
             body["password"] = password
